BioclimModel-class: BioclimModel S4 Class

BioclimModel-classR Documentation

BioclimModel S4 Class

Description

An S4 class that wraps a C++ BioclimModel object via an opaque external pointer handle, following the terra package pattern for C++ object handles. All 19 bioclimatic variable computations are delegated to the underlying C++ object via Rcpp.

Value

An S4 object of class BioclimModel wrapping a C++ BioclimModel instance via an externalptr handle in slot pntr.

Slots

pntr

An externalptr to the underlying C++ BioclimModel object.


xbioclim documentation built on Oct. 5, 2026, 5:08 p.m.