Skip to contents

S4 method implementations for all 19 bioclimatic variable functions and bioclim that dispatch to the underlying C++ object via Rcpp when the first argument is a BioclimModel-class instance.

Value

For bio01–bio19: a single numeric value with the corresponding bioclimatic variable computed from the monthly climate data stored in the object. For bioclim: a named numeric vector of length 19 (bio01 through bio19).