clear_messages: Clear all stored messages

View source: R/messages.R

clear_messagesR Documentation

Clear all stored messages

Description

Discards all error and warning messages currently held in the xbioclim message store. This is called automatically by check_messages() after propagating messages to R conditions, but you can call it manually to reset state between operations.

Usage

clear_messages()

Value

Invisible NULL.

See Also

bioclim_errors(), bioclim_warnings()

Examples

clear_messages()
has_error()    # FALSE
has_warning()  # FALSE

xbioclim documentation built on Oct. 5, 2026, 5:08 p.m.