dot-resolve_climate_input: Resolve a climate input to a character vector of file paths

.resolve_climate_inputR Documentation

Resolve a climate input to a character vector of file paths

Description

Accepts a character vector (length 1 or 12) or a terra::SpatRaster (12 layers). Returns a character vector of length 1 or 12 and validates that all files exist.

Usage

.resolve_climate_input(x, name)

Arguments

x

The input to resolve.

name

Variable name for error messages.

Value

Character vector of length 1 or 12.


xbioclim documentation built on Oct. 5, 2026, 5:08 p.m.