Controls the number of threads used in the per-pixel inner loop inside each tile. Values less than 1 are clamped to 1.
Arguments
- xptr
External pointer returned by
engine_create.- n
Integer scalar: number of threads.
Controls the number of threads used in the per-pixel inner loop inside each tile. Values less than 1 are clamped to 1.
External pointer returned by engine_create.
Integer scalar: number of threads.