Skip to contents

This function is called by C++ routines (via .Call) or internal R helpers to record a warning without immediately issuing an R condition. Call check_messages() afterwards to convert the stored message into a proper R warning.

Usage

push_warning(msg)

Arguments

msg

A single character string describing the warning.

Value

Invisible NULL.