quarter_argmax: Find the starting month of the quarter with the maximum sum

View source: R/primitives.R

quarter_argmaxR Documentation

Find the starting month of the quarter with the maximum sum

Description

Find the starting month of the quarter with the maximum sum

Usage

quarter_argmax(x, na.rm = FALSE)

Arguments

x

A numeric vector of length 12 (monthly values).

na.rm

Logical. If TRUE, missing values are skipped; a quarter needs at least one non-missing value to be considered.

Value

An integer (1-12) indicating the starting month.


xbioclim documentation built on Oct. 5, 2026, 5:08 p.m.