quarter_values: Get the 3-month values for a quarter starting at a given...

View source: R/primitives.R

quarter_valuesR Documentation

Get the 3-month values for a quarter starting at a given month

Description

Get the 3-month values for a quarter starting at a given month

Usage

quarter_values(x, start)

Arguments

x

A numeric vector of length 12 (monthly values).

start

The starting month (1-12).

Value

A numeric vector of length 3.


xbioclim documentation built on Oct. 5, 2026, 5:08 p.m.