An S4 class that wraps a C++ BioclimModel object via an opaque
external pointer handle, following the terra package pattern for C++ object
handles. All 19 bioclimatic variable computations are delegated to the
underlying C++ object via Rcpp.
An S4 class that wraps a C++ BioclimModel object via an opaque
external pointer handle, following the terra package pattern for C++ object
handles. All 19 bioclimatic variable computations are delegated to the
underlying C++ object via Rcpp.