Discards all error and warning messages currently held in the xbioclim
message store. This is called automatically by check_messages() after
propagating messages to R conditions, but you can call it manually to reset
state between operations.
Examples
clear_messages()
has_error() # FALSE
#> [1] FALSE
has_warning() # FALSE
#> [1] FALSE