| clear_messages | R Documentation |
Discards all error and warning messages currently held in the xbioclim
message store. This is called automatically by check_messages() after
propagating messages to R conditions, but you can call it manually to reset
state between operations.
clear_messages()
Invisible NULL.
bioclim_errors(), bioclim_warnings()
clear_messages()
has_error() # FALSE
has_warning() # FALSE
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.