| cuda_device_info | R Documentation |
Returns a named list with hardware information about the first CUDA-capable GPU. Returns an empty list when no CUDA device is available or when the package was built without CUDA.
cuda_device_info()
Named list with:
Character: GPU model name.
Numeric: total global memory in gigabytes.
Character: e.g. "8.0" for A100.
An empty list when no CUDA device is detected.
has_cuda, cuda_device_count
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.