This function is called by C++ routines (via .Call) or internal R helpers
to record an error without immediately throwing an R condition. Call
check_messages() afterwards to convert the stored message into a proper
R error.
This function is called by C++ routines (via .Call) or internal R helpers
to record an error without immediately throwing an R condition. Call
check_messages() afterwards to convert the stored message into a proper
R error.