| push_warning | R Documentation |
This function is called by C++ routines (via .Call) or internal R helpers
to record a warning without immediately issuing an R condition. Call
check_messages() afterwards to convert the stored message into a proper
R warning.
push_warning(msg)
msg |
A single character string describing the warning. |
Invisible NULL.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.